Processor.processor.ListnerStats — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.processor.ListnerStats

class Processor.processor.ListnerStats(messages: int = 0, last_message_time: datetime.datetime = datetime.datetime(2022, 11, 10, 21, 20, 56, 629188))
  __init__(messages: int = 0, last_message_time: datetime = datetime.datetime(2022, 11, 10, 21, 20, 56, 629188)) → None

  Methods

  `__init__`([messages, last_message_time]) |

  Attributes

  `last_message_time` |
  `messages` |